#
# spec file for package dvb
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if !%{defined snapver}
%define snapver  20150120
%endif

Name:           dvb
BuildRequires:  fdupes
BuildRequires:  libusb-devel
%if 0%{?suse_version} >= 1210
BuildRequires:  libv4l-devel >= 0.8.4
%endif
BuildRequires:  xz
Url:            http://linuxtv.org/
PreReq:         %fillup_prereq %insserv_prereq
Version:        1.1.1%{?snapver:_%snapver}
Release:        1.1
Summary:        Tools for Digital (DVB) TV Cards
License:        GPL-2.0+ and LGPL-2.1+
Group:          Hardware/TV
Source:         dvb-apps-%{version}.tar.xz
Source2:        rcdvb
Source3:        sysconfig.dvb
Patch:          dvb-apps-dvbnet.diff
Patch1:         dvb-includes.diff
Patch2:         dvb-femon-01-status-is-common.patch
Patch3:         dvb-femon-02-SNR-in-dB.patch
Patch4:         dvb-femon-03-handle-EOPNOTSUPP.patch
# PATCH-FIX-OPENSUSE: dvb-scan-dont-segfault.patch, upstream is basically dead, but still avoid insstant segfault in usage() function -- seife
Patch5:         dvb-scan-dont-segfault.patch
# PATCH-FEATURE-OPENSUSE: dvb-opensuse-integration, openSUSE integration -- jdelvare
Patch6:         dvb-opensuse-integration.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       dtv-scan-tables

%description
DVB tools and transponder files useful for DVB TV Cards

%package -n dvb-devel
Summary:        Development files for DVB-related libraries
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
Requires:       dvb = %{version}
Requires:       glibc-devel

%description -n dvb-devel
Files needed for the development of DVB TV applications and tools.
Header files are included for the following libraries: libdvbapi,
libdvbcfg, libdvben50221, libdvbsec, libesg and libucsi.

%prep
%setup -q -n dvb-apps-%{version}
%patch
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
find -name .hg -type d | xargs rm -rfv
find -name .cvsignore -type f | xargs rm -fv
find -name '*.orig' -type f | xargs rm -fv

%build
rm -rf include/linux
make %{?_smp_mflags} CFLAGS="%{optflags} -fno-strict-aliasing -fPIC" \
	CC=gcc \
	bindir=%{_bindir} \
	libdir=%{_libdir} \
	V=1 \
	ttusb_dec_reset=1

%install
export DESTDIR=%{buildroot}
## directories
install -d -m 755 $DESTDIR/usr/{,s}bin $DESTDIR/etc/init.d $DESTDIR/usr/include \
	$DESTDIR/var/adm/fillup-templates
#
## docu
install -d -m 755 $DESTDIR%{_docdir}/dvb
install -m 644 README COPYING* $DESTDIR%{_docdir}/dvb
#
##
make \
	bindir=%{_bindir} \
	libdir=%{_libdir} \
	prefix=%{_prefix} \
	includedir=%{_includedir} \
	DESTDIR=%{buildroot} \
	install
install -d -m 755 $DESTDIR/%{_docdir}/%{name}/szap
install -m 644 util/szap/README $DESTDIR/%{_docdir}/%{name}/szap
install -m 644 util/ttusb_dec_reset/README $DESTDIR/%{_docdir}/%{name}/README.ttusb_dec_reset
install -m 644 util/av7110_loadkeys/README $DESTDIR/%{_docdir}/%{name}/README.av7110_loadkeys
#
# dvbnet
install -m 644 util/dvbnet/net_start.* $DESTDIR/%{_docdir}/%{name}/
## sysconfig & init
install -m 644 %{SOURCE3} $DESTDIR/var/adm/fillup-templates
ln -sf /etc/init.d/dvb $DESTDIR/usr/sbin/rcdvb
install -m 755 %{SOURCE2} $DESTDIR/etc/init.d/dvb
#
# scan is too generic a name, rename to dvbscan/atscscan to avoid conflicts
mv %{buildroot}%{_bindir}/scan %{buildroot}%{_bindir}/dvbscan
ln %{buildroot}%{_bindir}/dvbscan %{buildroot}%{_bindir}/atscscan
#
%fdupes $RPM_BUILD_ROOT

%preun
%stop_on_removal dvb

%post
%{fillup_and_insserv dvb}

%postun
%restart_on_update dvb
%insserv_cleanup

%files
%defattr(-, root, root)
%doc %{_docdir}/dvb
%{_datadir}/dvb
/var/adm/fillup-templates/sysconfig.dvb
%config /etc/init.d/dvb
/usr/sbin/rcdvb
/usr/bin/*
%{_libdir}/*.so

%files -n dvb-devel
%defattr(-, root, root)
%{_includedir}/libdvbapi
%{_includedir}/libdvbcfg
%{_includedir}/libdvben50221
%{_includedir}/libdvbsec
%{_includedir}/libesg
%{_includedir}/libucsi

%changelog
* Wed Jan 21 2015 jdelvare@suse.com
- dvb-opensuse-integration.patch: Instead of excluding files from
  the package, don't build them in the first place, this is more
  efficient.
* Tue Jan 20 2015 jdelvare@suse.com
- Update to the latest upstream snapshot (20150120)
  * Scan data files are no longer included so we don't have to
    delete them.
* Thu Jan  1 2015 seife+obs@b1-systems.com
- add dvb-scan-dont-segfault.patch to avoid dvbscan segfault in
  usage message if called without any parameter
* Tue Dec 10 2013 jdelvare@suse.com
- Remove dvb-ttpci-01.fw-2622 as license is unknown.
- Install COPYING* as %%doc.
* Fri Oct 18 2013 jdelvare@suse.com
- License clarification: the main dvb package also contains
  LGPL-2.1+ code.
* Thu Oct 17 2013 jdelvare@suse.com
- Rename scan to dvbscan/atscscan, to avoid collisions.
* Tue Oct  1 2013 jdelvare@suse.com
- Make the dvb-devel package description somewhat more verbose, to
  make rpmlint happy.
* Tue Oct  1 2013 jdelvare@suse.com
- dvb-femon-01-status-is-common.patch: femon: Share common code
  (bnc#843473).
- dvb-femon-02-SNR-in-dB.patch: femon: Display SNR in dB
  (bnc#843473).
- dvb-femon-03-handle-EOPNOTSUPP.patch: femon: Handle -EOPNOTSUPP
  (bnc#843474).
* Tue Oct  1 2013 jdelvare@suse.com
- New subpackage dvb-devel, containing header files needed to build
  third-party DVB applications (bnc#832195).
* Sun Jan 20 2013 jslaby@suse.com
- add Require for dtv-scan-tables (this is where scan data currently are)
- some rpmlint fixes
* Fri Nov 30 2012 jslaby@suse.com
- update to 1.1.1_20120913
  * ar, br, cz, hu scan data updated
- remove cz-Kojal scanfile. It's superseded by the new cz data.
* Thu May 31 2012 lnussel@suse.de
- update to 1.1.1_20120410
  * updated scan files and some bug fixes
* Sat Mar 24 2012 jdelvare@suse.de
- channels-fr-Gironde.patch Fix frequency tables for cities in
  Gironde, France.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Jul  7 2011 idonmez@novell.com
- Add dvb-apps-v4l-2.6.38.patch: use the new v4l interface
* Wed May 12 2010 lnussel@suse.de
- update to 1.1.1_20100509
* Sun Jan  3 2010 jslaby@suse.de
- remove dvbscan from rpm (incomplete and defunct)
- add cz-kojal scan files
* Tue Nov 24 2009 crrodriguez@opensuse.org
- refresh patches with fuzz=0
* Mon Nov  9 2009 lnussel@suse.de
- update to 1.1.1_20091108
  * random bugfixes
  * update of tuning data
* Thu May  7 2009 ro@suse.de
- fix build with current includes (add include stdint where needed)
* Mon Mar 31 2008 lnussel@suse.de
- update firmware to version 2622
- update to current development snapshot
  * mostly scan file updates
* Thu Aug  9 2007 olh@suse.de
- remove private include/linux/ files
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
* Fri Mar 16 2007 lnussel@suse.de
- remove /lib/firmware as it's now in the filesystem package
* Mon Mar  5 2007 lnussel@suse.de
- update to current development snapshot
* Mon Sep 11 2006 lnussel@suse.de
- add -fPIC to CFLAGS
* Fri Sep  8 2006 lnussel@suse.de
- update to current development snapshot
* Fri Mar 10 2006 lnussel@suse.de
- add modalias to Supplements (#156864)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 20 2005 lnussel@suse.de
- don't install the test programs anymore
* Wed Oct 19 2005 lnussel@suse.de
- move headers to fix build of vdr
- apply separate patches
- move firmware to /lib/firmware
* Thu Sep 29 2005 lnussel@suse.de
- update to current CVS
* Wed Jul 20 2005 lnussel@suse.de
- update to last 'stable' CVS version
  * initial transponders now in /usr/share/dvb/scan
* Thu Jul  7 2005 lnussel@suse.de
- update to current CVS
- new firmware 261f
* Fri Jun 17 2005 lnussel@suse.de
- update to current CVS
* Tue Mar  8 2005 lnussel@suse.de
- remove no longer working check for hotplug (#71233)
* Tue Feb  1 2005 lnussel@suse.de
- fix another __user for 8.2
* Mon Jan 31 2005 lnussel@suse.de
- fix build on 8.2
- new firmware 261d
* Fri Jan 21 2005 lnussel@suse.de
- update dvb-apps to current cvs
- make list of modules to load configurable
- don't unload modules at shutdown
* Sun Oct  3 2004 lnussel@suse.de
- add some notes about hwcfg files to README.SuSE
* Fri Sep 17 2004 lnussel@suse.de
- don't depend on 'kernelversion' script (#44858)
* Fri Aug 13 2004 lnussel@suse.de
- install dvb_net.sh and dvb_net.pl as docu since they need to be manually
  edited to be actually useful anyways
* Thu Aug 12 2004 lnussel@suse.de
- update to current CVS
- finally drop km_dvb
* Sun Jun 20 2004 lnussel@suse.de
- fix build on 8.1
* Sun Mar 28 2004 lnussel@suse.de
- load dvb-bt8xx if bttv module is loaded (#36969)
* Fri Mar 19 2004 lnussel@suse.de
- change hotplug-beta -> hotplug in initscript
- remove left over .orig files
* Sat Feb 14 2004 lnussel@suse.de
- fix sysconfig meta data
* Fri Feb 13 2004 lnussel@suse.de
- add patch linuxtv-dvb-1.1.0-zaptime.diff for faster channel switching
- build 1.1.0 driver on kernel 2.4 per default
- check for firmware agent instead of hotplug-beta
- remove obsolete sysconfig variables. Module parameters should be set in
  modprobe.conf instead
- scan program is now /usr/bin/dvbscan
* Fri Feb  6 2004 lnussel@suse.de
- update to linuxdvb-dvb-apps-1.1.0
- include linuxtv-dvb-1.1.0 in km_dvb but keep old driver for kernel
  2.4
- use upstream version number rather than the date of the CVS
  snapshot. That means version downgrade unfortunately.
- rename README.SuSE -> dvb-README.SuSE
- rename Makefile.module -> dvb-Makefile.module
- update README.km_dvb and spec files
* Mon Jan 19 2004 lnussel@suse.de
- add /usr/lib/hotplug/firmware as directory since dvb doesn't depend on
  hotplug-beta which normally owns the directory
- clean up neededforbuild
* Sat Jan 17 2004 lnussel@suse.de
- update to current CVS
- modify init script to work with kernel 2.6
- add firmware for 2.6 kernel modules. hotplug-beta is needed to load it
* Mon Nov 17 2003 lnussel@suse.de
- update to current CVS
- install transponder files for scan
* Fri Nov 14 2003 lnussel@suse.de
- fix filelist for older distributions
* Tue Oct 28 2003 lnussel@suse.de
- update to current CVS
- build as user
- add README for km_dvb
- add spec file for rebuilding km_dvb for all kernels
- include README.scan and FAQ (#30308)
- fix symlink to initscript
* Tue Oct  7 2003 duwe@suse.de
- update to current CVS
- ability to use -I/usr/include/dvb for applications,
  as discussed with werner, stepan & upstream maintainers
- added scan program, per #30308
* Tue Sep  9 2003 agruen@suse.de
- Fix import of linux/unistd.h on x86_64: Needs __NO_STUBS.
* Thu Sep  4 2003 duwe@suse.de
- fixed AV711x I-Frame (stills) playback, required for vdr cutting,
  (Bug #30049)
* Tue Aug 19 2003 lnussel@suse.de
- clean up sysconfig file to properly work with yast2 sysconfig
  editor
- add dvb-modules.spec to km_dvb for easy rebuilding of kernel
  modules on older distributions
* Mon Aug 18 2003 duwe@suse.de
- CVS update, new frontend drivers.
- more consistent frontend module handling in rc script,
  better remote support, a metadata update, all merged
  from Ludwig's proposal.
  (Bug #28872 should be fixed, if it was an issue).
* Thu Jun 19 2003 stepan@suse.de
- update from CVS - works stable with vdr 1.2.1
* Fri Jun 13 2003 kukuk@suse.de
- Add missing directories to filelist
* Tue May 20 2003 ro@suse.de
- removed CVS subdirs
- moved includes to /usr/include/dvb (fix clash with glibc-devel)
* Wed May  7 2003 stepan@suse.de
- CVS update, May 7th
* Wed Apr  9 2003 duwe@suse.de
- CVS update, corresponds to about 1.0.0-pre3
* Mon Feb 24 2003 duwe@suse.de
- Allow alternate firmware to be of different size.
* Mon Feb 24 2003 duwe@suse.de
- CVS update, should fix major bug #23852
* Mon Feb 10 2003 duwe@suse.de
- update to current CVS version:
  + includes Metzler Bros. Ci-LL support
  - mpegtools are gone and need a separate package.
* Wed Jan 22 2003 duwe@suse.de
- tested and fixed "alternate-firmware" patch
* Mon Jan 20 2003 duwe@suse.de
- update to today's CVS snapshot (bsru6 is now called stv0299 )
- added sysconfig metadata (#22639)
- implemented run-time loading of alternate firmware
  to aid development (maybe of GPL'ed firmware ?) -- not yet tested
* Thu Dec  5 2002 duwe@suse.de
- rc script now finally works
- other minor fixes from the CVS
* Wed Dec  4 2002 duwe@suse.de
- current CVS snapshot : new API, new directory layout
* Mon Oct 14 2002 uli@suse.de
- update -> 20020623 (patched to allow simultaneous recording and
  playback on a single card)
* Wed Aug 14 2002 poeml@suse.de
- fix comment in init script
* Thu Aug  1 2002 uli@suse.de
- added Prereqs
* Wed May  8 2002 ro@suse.de
- fixed compilation with latest gcc (again)
* Fri Apr 26 2002 uli@suse.de
- updated README.SuSE (fixes bug #16027)
* Thu Apr 25 2002 uli@suse.de
- (hopefully) fixed for new kernel
* Tue Apr 23 2002 ro@suse.de
- make it compile with gcc-3.1
* Tue Apr  9 2002 uli@suse.de
- moved config from rc.config to sysconfig (bug #15612)
* Fri Mar  1 2002 uli@suse.de
- removed dvbd (doesn't work with the NAPI)
- made firmware external again
* Fri Feb 15 2002 uli@suse.de
- "rcdvb status" returns 3 if down (bug #13316)
* Mon Feb 11 2002 uli@suse.de
- update -> 0.9.4 (release)
* Thu Feb  7 2002 uli@suse.de
- replaced get_fast_time() with do_gettimeofday() for 2.4.18-pre8
* Mon Feb  4 2002 uli@suse.de
- added MODULE_LICENSE() statements
* Fri Feb  1 2002 uli@suse.de
- added pte-highmem fix by andrea
* Fri Jan 18 2002 uli@suse.de
- update -> 20020116 (better support for DVB-T/C cards)
* Thu Nov 22 2001 uli@suse.de
- eliminated START_DVB
* Mon Oct 15 2001 uli@suse.de
- export symbol DmxDevDVRPoll in dmxdev.o (needed by dvb.o)
- renamed dif
* Thu Oct 11 2001 ro@suse.de
- fix typo, it's -DEXPORT_SYMTAB not -DDEXPORT_SYMTAB
* Wed Oct 10 2001 ro@suse.de
- added -DEXPORT_SYMTAB to EXTRA_CFLAGS in driver Makefile
* Fri Sep 21 2001 uli@suse.de
- init script: fixed module loading/unloading order, no more network
  device, no unloading of autoclean modules, fixed crystal/ti option
* Mon Aug 20 2001 uli@suse.de
- forgot rcdvb symlink
  (also forgot to pack the init script, but I don't really like to
  talk about that...)
* Mon Aug 20 2001 uli@suse.de
- update -> 0.9-20010817
- replaced dvb_*mod scripts with proper init script
* Tue Aug  7 2001 uli@suse.de
- update -> 0.9-20010803
* Mon Jul 30 2001 uli@suse.de
- update -> 0.9-20010729 (reqd. for vdr 0.85)
* Wed Jun 27 2001 uli@suse.de
- fixed dvb_*mod scripts
- added test apps to package (one of which is actually a decent MPEG
  player)
- bzipped tarballs
* Tue Jun 26 2001 uli@suse.de
- added missing header files
* Tue Jun 26 2001 uli@suse.de
- update -> 0.9-20010618
* Wed May 16 2001 uli@suse.de
- added missing firmware file
- dvb_insmod: use kernel i2c-core, videodev to avoid hangs
* Mon Mar 26 2001 uli@suse.de
- update -> 0.8.2
* Mon Mar 12 2001 uli@suse.de
- no longer using XFree86 3.x libs
* Thu Feb 22 2001 uli@suse.de
- update -> 0.8.1 (should do better with 2.4 kernels)
* Mon Feb 19 2001 uli@suse.de
- in libdvb renamed struct Picture to DVB_Picture (conflicts with X)
* Wed Dec  6 2000 uli@suse.de
- added missing stuff to km_dvb
- added ost devices to dvb
* Mon Dec  4 2000 uli@suse.de
- update -> 0.8
- removed avpes2mpeg (output now defaults to program stream)
* Thu Nov 23 2000 uli@suse.de
- linking against DGA/VM libs from XFree86 3 to ensure compatibility
* Wed Nov  8 2000 uli@suse.de
- added missing firmware file
- added absolute path to firmware file in dvb module
* Sun Nov  5 2000 ro@suse.de
- fixed neededforbuild
* Mon Oct 23 2000 ro@suse.de
- fixed includes
* Fri Sep  1 2000 uli@suse.de
- initial package
